@@ -1,6 +1,6 @@
-#' Simulated preliminary mice uncensored data
+#' Simulated preliminary animals uncensored data
 #'
-#' @description The \code{mice1} data frame has 18 rows and 3 columns, with all uncensored observations.
+#' @description The \code{animals1} data frame has 18 rows and 3 columns, with all uncensored observations.
 #'
 #' @format This data frame contains the following columns:
 #'
@@ -13,13 +13,13 @@
 #'   \item{\code{Tx}}{treatment indicator. \code{0} denotes the placebo group and \code{1} the treatment group.}
 #'
 #'   }
-#' @usage data(mice1)
+#' @usage data(animals1)
 #'
-"mice1"
+"animals1"
 
-#' Simulated preliminary mice censored data
+#' Simulated preliminary animals censored data
 #'
-#' @description The \code{mice2} data frame has 18 rows and 4 columns, with some censored observations.
+#' @description The \code{animals2} data frame has 18 rows and 4 columns, with some censored observations.
 #'
 #' @format This data frame contains the following columns:
 #'
@@ -34,7 +34,7 @@
 #'   \item{\code{status}}{event status. \code{0} denotes right-censoring and \code{1} the event occurs.}
 #'
 #'   }
-#' @usage data(mice2)
+#' @usage data(animals2)
 #'
-"mice2"
+"animals2"
 
